=========
Optionals
=========

Satella provides a set of routines to use with optionals:

.. autofunction:: satella.coding.optionals.call_if_nnone

.. autofunction:: satella.coding.optionals.iterate_if_nnone

.. autoclass:: satella.coding.optionals.Optional
    :members:

To extract the value from an :class:`~satella.coding.optionals.Optional` you may use:

.. autofunction:: satella.coding.optionals.extract_optional
